@@ -320,6 +320,7 @@ class AlgebraicMixin(ParameterMixin, CompoundMixin, BaseModel):
         args: List[str],
         check_consistency: bool = True,
         sort_modules: bool = True,
+        **meta_info: Dict[str, Any],
     ) -> None:
 
         compounds = []
@@ -341,46 +342,11 @@ class AlgebraicMixin(ParameterMixin, CompoundMixin, BaseModel):
             derived_compounds=derived_compounds,
             modifiers=modifiers,
             parameters=parameters,
+            dynamic_variables=None,
             args=args,
             check_consistency=check_consistency,
             sort_modules=sort_modules,
-        )
-
-    def update_algebraic_module_from_args(
-        self,
-        module_name: str,
-        function: Union[Callable[..., float], Callable[..., Iterable[float]]]
-        | None = None,
-        derived_compounds: List[str] | None = None,
-        args: List[str] | None = None,
-        check_consistency: bool = True,
-        sort_modules: bool  = True,
-    ) -> None:
-        if args is None:
-            compounds = self.algebraic_modules[module_name].compounds
-            modifiers = self.algebraic_modules[module_name].modifiers
-            parameters = self.algebraic_modules[module_name].parameters
-        else:
-            compounds = []
-            modifiers = []
-            parameters = []
-            for i in args:
-                if i in self.parameters:
-                    parameters.append(i)
-                elif i in self.compounds:
-                    compounds.append(i)
-                else:
-                    modifiers.append(i)
-        self.update_algebraic_module(
-            module_name=module_name,
-            function=function,
-            compounds=compounds,
-            derived_compounds=derived_compounds,
-            modifiers=modifiers,
-            parameters=parameters,
-            args=args,
-            check_consistency=check_consistency,
-            sort_modules=sort_modules,
+            **meta_info,
         )
 
     def add_algebraic_modules(
@@ -410,6 +376,7 @@ class AlgebraicMixin(ParameterMixin, CompoundMixin, BaseModel):
         args: List[str] | None = None,
         check_consistency: bool = True,
         sort_modules: bool = True,
+        **meta_info: Dict[str, Any],
     ) -> None:
         """Update an existing reaction."""
         module = self.algebraic_modules[module_name]
@@ -466,16 +433,61 @@ class AlgebraicMixin(ParameterMixin, CompoundMixin, BaseModel):
             self._check_module_consistency(module, check_ids=derived_have_changed)
         if sort_modules:
             self._sort_algebraic_modules()
+        self.update_meta_info("modules", meta_info)
 
-    def update_algebraic_modules(self, modules: dict) -> None:
+    def update_algebraic_module_from_args(
+        self,
+        module_name: str,
+        function: Union[Callable[..., float], Callable[..., Iterable[float]]]
+        | None = None,
+        derived_compounds: List[str] | None = None,
+        args: List[str] | None = None,
+        check_consistency: bool = True,
+        sort_modules: bool = True,
+        **meta_info: Dict[str, Any],
+    ) -> None:
+        if args is None:
+            compounds = self.algebraic_modules[module_name].compounds
+            modifiers = self.algebraic_modules[module_name].modifiers
+            parameters = self.algebraic_modules[module_name].parameters
+        else:
+            compounds = []
+            modifiers = []
+            parameters = []
+            for i in args:
+                if i in self.parameters:
+                    parameters.append(i)
+                elif i in self.compounds:
+                    compounds.append(i)
+                else:
+                    modifiers.append(i)
+        self.update_algebraic_module(
+            module_name=module_name,
+            function=function,
+            compounds=compounds,
+            derived_compounds=derived_compounds,
+            modifiers=modifiers,
+            parameters=parameters,
+            dynamic_variables=None,
+            args=args,
+            check_consistency=check_consistency,
+            sort_modules=sort_modules,
+            **meta_info,
+        )
+
+    def update_algebraic_modules(
+        self, modules: dict, meta_info: dict | None = None
+    ) -> None:
         """Update multiple algebraic modules
 
         See Also
         --------
         update_algebraic_module
         """
+        meta_info = {} if meta_info is None else meta_info
         for name, module in modules.items():
-            self.update_algebraic_module(name, **module)
+            info = meta_info.get(name, {})
+            self.update_algebraic_module(name, **module, **info)
 
     def update_module_meta_info(self, module: str, meta_info: dict) -> None:
         """Update meta info of an algebraic module.
