@@ -14,7 +14,7 @@ from types import TracebackType
 from typing import Any, Dict, List, Optional
 
 import libsbml
-from typing_extensions import Self, TypeAlias
+from typing_extensions import Self
 
 from .utils import convert_id_to_sbml, warning_on_one_line
 
@@ -143,6 +143,7 @@ class BaseModel(ABC):
         ----------
         component : str
             Name of the component. Available components depend of the model type
+            One of "modules", "compounds",
         meta_info : dict
             Meta info for the component. Available keys depend on the
             component
