@@ -85,10 +85,7 @@ class CompoundMixin(BaseModel):
         """
         meta_info = {} if meta_info is None else meta_info
         for compound in compounds:
-            try:
-                info = meta_info[compound]
-            except KeyError:
-                info = {}
+            info = meta_info.get(compound, {})
             self.add_compound(compound=compound, **info)
 
     def update_compound_meta_info(self, compound: str, meta_info: dict) -> None:
