@@ -1,6 +1,7 @@
 from __future__ import annotations
 
 __all__ = [
+    "DerivedStoichiometry",
     "Model",
     "LabelModel",
     "LinearLabelModel",
@@ -14,6 +15,6 @@ __all__ = [
     "_Simulate",
 ]
 
-from .models import LabelModel, LinearLabelModel, Model
+from .models import LabelModel, LinearLabelModel, Model, DerivedStoichiometry
 from .simulators import Simulator, _LabelSimulate, _LinearLabelSimulate, _Simulate
 from .utils import algebraicfunctions, mca, ratefunctions, ratelaws
