@@ -376,6 +376,11 @@ class _BaseSimulator(Generic[BASE_MODEL_TYPE], ABC):
             for t, result in zip(time, results)
         ]
 
+    def get_new_y0(self) -> dict[str, float] | None:
+        if (res := self.get_results_df()) is None:
+            return None
+        return dict(res.iloc[-1])
+
     def store_results_to_file(self, filename: str, filetype: str = "json") -> None:
         """Store the simulation results into a json or pickle file.
 
