@@ -5,7 +5,8 @@ __all__ = [
 ]
 
 import copy
-import math
+
+import math  # noqa: F401, math needs to be imported for sbml functions
 import re
 import warnings
 from collections import defaultdict
@@ -17,7 +18,6 @@ import numpy as np
 import sympy
 
 from ..ode import Model
-from ..typing import Array
 from .data import (
     AlgebraicRule,
     AssignmentRule,
@@ -525,7 +525,7 @@ class Parser:
             return None
 
         for func_id, function in self.parsed_functions.items():
-            func_pattern = re.compile(f"{func_id}\(.+\)")
+            func_pattern = re.compile(rf"{func_id}\(.+\)")
             matches = re.findall(func_pattern, rule_body)
             for match in matches:
                 func_body = function.function_body
